@@ -48,7 +48,11 @@ launchFuture.CallrFutureBackend <- local({
   ## MEMOIZATION
   evalFuture <- import_future("evalFuture")
   getFutureData <- import_future("getFutureData")
-  with_stealth_rng <- import_future("with_stealth_rng")
+  with_stealth_rng <- if (packageVersion("processx") >= "3.8.6") {
+    identity
+  } else {
+    import_future("with_stealth_rng")
+  }
   
   cmdargs <- NULL
 
@@ -126,7 +130,8 @@ launchFuture.CallrFutureBackend <- local({
 
 
     ## Launch
-    ## WORKAROUND: callr::r_bg() updates the RNG state
+    ## WORKAROUND: callr::r_bg() -> ... -> processx:::get_id() updates
+    ## the RNG state. This was fixed in processx 3.8.6 (2025-02-21).
     with_stealth_rng({
       future[["process"]] <- r_bg(func, args = r_bg_args, stdout = stdout, stderr = stderr, cmdargs = cmdargs, supervise = supervise)
     })
@@ -456,6 +461,10 @@ await <- function(future, ...) {
       if (FutureRegistry(reg, action = "contains", future = future)) {
         FutureRegistry(reg, action = "remove", future = future)
       }
+      
+      ## Finalize the 'callr' process, which includes remove any temporary
+      ## files that it created
+      process$finalize()
     }
 
     ## Failed to launch?
@@ -526,6 +535,10 @@ await <- function(future, ...) {
   
   reg <- backend[["reg"]]
   FutureRegistry(reg, action = "remove", future = future)
+
+  ## Finalize the 'callr' process, which includes remove any temporary
+  ## files that it created
+  process$finalize()
   
   result
 } # await()
